@@ -10,6 +10,7 @@ SEARCH_FORM_NAME = 'kerne_vis_koeretoej{actionForm.soegeord}'
 
 CAPITALIZED_BRANDS = ['VW', 'BMW']
 
+
 def get_car_details(license_plate, details=False):
     session = requests.Session()
 
@@ -35,7 +36,7 @@ def _get_token(session):
     response = session.get('https://motorregister.skat.dk/dmr-front/appmanager/skat/dmr?_nfls=false&_nfpb=true&_pageLabel=vis_koeretoej_side')
 
     soup = BeautifulSoup(response.content)
-    token = soup.find('input', attrs={'name':'dmrFormToken'})['value']
+    token = soup.find('input', attrs={'name': 'dmrFormToken'})['value']
 
     return token
 
@@ -50,13 +51,14 @@ def _min_car_info(session, payload):
             "error": 404
         }
 
-    values = [div.find_all('span', attrs={'class': 'value'}) for div in soup.find_all('div', attrs={'class': 'bluebox'})]
+    values = [div.find_all('span', attrs={'class': 'value'})
+              for div in soup.find_all('div', attrs={'class': 'bluebox'})]
     model_string = values[0][1].text
     year_string = values[1][1].text
 
     model_array = model_string.split(', ')
 
-    #Nice formatting of car make - except if VW
+    # Nice formatting of car make - except if VW or BMW
     car_make = model_array[0].title()
 
     if not car_make in CAPITALIZED_BRANDS:
@@ -77,13 +79,11 @@ def _technical_car_info(session):
 
     motor = soup.find_all(text=re.compile('Motor osv.'))
     motor_div = motor[0].parent.parent
-    motor_vals = [div.find_all('span') for div in motor_div.find_all('div', 'colValue')]
+    motor_vals = [div.find_all('span')
+                  for div in motor_div.find_all('div', 'colValue')]
 
     gasoline_type = motor_vals[1][0].text
-
     mileage_value = motor_vals[2][0].text
-    mileage_unit = motor_vals[2][1].text.strip()
-    #mileage = '{value} {unit}'.format(value=mileage_value, unit=mileage_unit)
 
     try:
         mileage = float(mileage_value.replace(',', '.'))
@@ -92,7 +92,8 @@ def _technical_car_info(session):
 
     car_body = soup.find_all(text=re.compile('Karrosseri'))
     car_body_div = car_body[0].parent.parent
-    car_body_vals = [div.find_all('span') for div in car_body_div.find_all('div', 'colValue')]
+    car_body_vals = [div.find_all('span')
+                     for div in car_body_div.find_all('div', 'colValue')]
 
     try:
         maximum_passengers = int(car_body_vals[9][0].text)
@@ -106,13 +107,12 @@ def _technical_car_info(session):
     }
 
 
-
-
 def _insurance_car_info(session):
     response = session.get('https://motorregister.skat.dk/dmr-front/appmanager/skat/dmr?_nfpb=true&_windowLabel=kerne_vis_koeretoej&kerne_vis_koeretoej_actionOverride=%2Fdk%2Fskat%2Fdmr%2Ffront%2Fportlets%2Fkoeretoej%2Fnested%2FvisKoeretoej%2FselectTab&kerne_vis_koeretoejdmr_tabset_tab=3&_pageLabel=vis_koeretoej_side')
     soup = BeautifulSoup(response.content)
 
-    insurance = [div.find_all('span', attrs={'class': 'value'}) for div in soup.find_all('div', attrs={'class': 'bluebox'})]
+    insurance = [div.find_all('span', attrs={'class': 'value'})
+                 for div in soup.find_all('div', attrs={'class': 'bluebox'})]
 
     insurance_company = insurance[0][0].text.strip()
     insurance_status = insurance[0][2].text.strip()
